==> directfb_0.9.25.1.orig.tar.gz: DirectFB-0.9.25.1/proxy/dispatcher/idirectfbpalette_dispatcher.h <==
/*
   (c) Copyright 2000-2002  convergence integrated media GmbH.
   (c) Copyright 2002-2004  convergence GmbH.

   All rights reserved.

   Written by Denis Oliver Kropp <dok@directfb.org>,
              Andreas Hundt <andi@fischlustig.de>,
              Sven Neumann <neo@directfb.org> and
              Ville Syrjl <syrjala@sci.fi>.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef __IDIRECTFBPALETTE_DISPATCHER_H__
#define __IDIRECTFBPALETTE_DISPATCHER_H__

#define IDIRECTFBPALETTE_METHOD_ID_AddRef                     1
#define IDIRECTFBPALETTE_METHOD_ID_Release                    2
#define IDIRECTFBPALETTE_METHOD_ID_GetCapabilities            3
#define IDIRECTFBPALETTE_METHOD_ID_GetSize                    4
#define IDIRECTFBPALETTE_METHOD_ID_SetEntries                 5
#define IDIRECTFBPALETTE_METHOD_ID_GetEntries                 6
#define IDIRECTFBPALETTE_METHOD_ID_FindBestMatch              7
#define IDIRECTFBPALETTE_METHOD_ID_CreateCopy                 8

#endif

==> directfb_1.2.10.0.orig.tar.gz: DirectFB-1.2.10/proxy/dispatcher/idirectfbpalette_dispatcher.h <==
/*
   (c) Copyright 2001-2008  The world wide DirectFB Open Source Community (directfb.org)
   (c) Copyright 2000-2004  Convergence (integrated media) GmbH

   All rights reserved.

   Written by Denis Oliver Kropp <dok@directfb.org>,
              Andreas Hundt <andi@fischlustig.de>,
              Sven Neumann <neo@directfb.org>,
              Ville Syrjälä <syrjala@sci.fi> and
              Claudio Ciccani <klan@users.sf.net>.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef __IDIRECTFBPALETTE_DISPATCHER_H__
#define __IDIRECTFBPALETTE_DISPATCHER_H__

#define IDIRECTFBPALETTE_METHOD_ID_AddRef                     1
#define IDIRECTFBPALETTE_METHOD_ID_Release                    2
#define IDIRECTFBPALETTE_METHOD_ID_GetCapabilities            3
#define IDIRECTFBPALETTE_METHOD_ID_GetSize                    4
#define IDIRECTFBPALETTE_METHOD_ID_SetEntries                 5
#define IDIRECTFBPALETTE_METHOD_ID_GetEntries                 6
#define IDIRECTFBPALETTE_METHOD_ID_FindBestMatch              7
#define IDIRECTFBPALETTE_METHOD_ID_CreateCopy                 8

#endif
